@@ -79,8 +79,8 @@ class ExtraTreesEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
             random_state
         )
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
             **DecisionTreeEdgeLabelPrediction.smoke_test_parameters(),
@@ -114,6 +114,6 @@ class ExtraTreesEdgeLabelPrediction(SklearnEdgeLabelPredictionAdapter):
             )
         }
     
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         return "Extra Trees Classifier"
\ No newline at end of file
