@@ -212,6 +212,6 @@ class GraphSAGEEdgeLabelPrediction(GCNEdgeLabelPrediction):
             }
         )
 
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         return "GraphSAGE"
\ No newline at end of file
