@@ -202,6 +202,6 @@ class KipfGCNEdgeLabelPrediction(GCNEdgeLabelPrediction):
             verbose=verbose,
         )
     
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         return "Kipf GCN"
\ No newline at end of file
