@@ -86,12 +86,12 @@ class DecisionTreeEdgePrediction(SklearnEdgePredictionAdapter):
             )
         }
 
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         return "Decision Tree Classifier"
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
             max_depth=1,
