@@ -13,17 +13,16 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
 
     MODELS = {
         "cbow": models.CBOW,
-        "skipgram": models.SkipGram
+        "skipgram": models.SkipGram,
+        "walkletscbow": models.WalkletsCBOW,
+        "walkletsskipgram": models.WalkletsSkipGram,
     }
 
     def __init__(
         self,
         model_name: str,
-        epochs: int = 10,
-        learning_rate: float = 0.01,
-        learning_rate_decay: float = 0.9,
         enable_cache: bool = False,
-        **kwargs
+        **model_kwargs: Dict
     ):
         """Create new abstract Node2Vec method.
 
@@ -31,16 +30,12 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
         --------------------------
         model_name: str
             The ensmallen graph embedding model to use.
-            Can either be the SkipGram of CBOW models.
-        epochs: int = 10
-            Number of epochs to train the model for.
-        learning_rate: float = 0.01
-            The learning rate to use to train the Node2Vec model.
-        learning_rate_decay: float = 0.9
-            Factor to reduce the learning rate for at each epoch. By default 0.9.
+            Can either be the SkipGram, WalkletsSkipGram, CBOW and WalkletsCBOW models.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
+        model_kwargs: Dict
+            Further parameters to forward to the model.
         """
         if model_name.lower() not in self.MODELS:
             raise ValueError(
@@ -50,24 +45,21 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
                 ).format(model_name)
             )
 
-        self._epochs = epochs
-        self._learning_rate = learning_rate
-        self._learning_rate_decay = learning_rate_decay
-        self._model_kwargs = kwargs
+        self._model_kwargs = model_kwargs
 
-        self._model = Node2VecEnsmallen.MODELS[model_name.lower()](**kwargs)
+        self._model = Node2VecEnsmallen.MODELS[model_name.lower()](**model_kwargs)
 
         super().__init__(
-            embedding_size=kwargs["embedding_size"],
+            embedding_size=model_kwargs["embedding_size"],
             enable_cache=enable_cache,
-            random_state=kwargs["random_state"]
+            random_state=model_kwargs["random_state"]
         )
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
-            embedding_size=5,
+            **AbstractEmbeddingModel.smoke_test_parameters(),
             epochs=1,
             window_size=1,
             walk_length=4,
@@ -80,20 +72,15 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
         """Returns parameters of the model."""
         return {
             **super().parameters(),
-            **self._model_kwargs,
-            **dict(
-                epochs=self._epochs,
-                learning_rate=self._learning_rate,
-                learning_rate_decay=self._learning_rate_decay,
-            )
+            **self._model_kwargs
         }
 
-    @staticmethod
-    def task_name() -> str:
+    @classmethod
+    def task_name(cls) -> str:
         return "Node Embedding"
 
-    @staticmethod
-    def library_name() -> str:
+    @classmethod
+    def library_name(cls) -> str:
         return "Ensmallen"
 
     def requires_nodes_sorted_by_decreasing_node_degree(self) -> bool:
@@ -109,33 +96,33 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
         verbose: bool = True
     ) -> EmbeddingResult:
         """Return node embedding."""
-        node_embedding = self._model.fit_transform(
-            graph,
-            epochs=self._epochs,
-            learning_rate=self._learning_rate,
-            learning_rate_decay=self._learning_rate_decay,
-            verbose=verbose
-        )
+        node_embeddings = self._model.fit_transform(graph)
+        if not isinstance(node_embeddings, list):
+            node_embeddings = [node_embeddings]
         if return_dataframe:
-            node_embedding = pd.DataFrame(
-                node_embedding,
-                index=graph.get_node_names()
-            )
+            node_names = graph.get_node_names()
+            node_embeddings = [
+                pd.DataFrame(
+                    node_embedding,
+                    index=node_names
+                )
+                for node_embedding in node_embeddings
+            ]
         return EmbeddingResult(
             embedding_method_name=self.model_name(),
-            node_embeddings=node_embedding
+            node_embeddings=node_embeddings
         )
 
-    @staticmethod
-    def requires_edge_weights() -> bool:
+    @classmethod
+    def requires_edge_weights(cls) -> bool:
         return False
 
-    @staticmethod
-    def requires_positive_edge_weights() -> bool:
+    @classmethod
+    def requires_positive_edge_weights(cls) -> bool:
         return True
 
-    @staticmethod
-    def can_use_edge_weights() -> bool:
+    @classmethod
+    def can_use_edge_weights(cls) -> bool:
         """Returns whether the model can optionally use edge weights."""
         return True
 
@@ -143,8 +130,8 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
         """Returns whether the model is parametrized to use edge weights."""
         return True
 
-    @staticmethod
-    def can_use_node_types() -> bool:
+    @classmethod
+    def can_use_node_types(cls) -> bool:
         """Returns whether the model can optionally use node types."""
         return True
 
@@ -152,8 +139,8 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
         """Returns whether the model is parametrized to use node types."""
         return self._model_kwargs["change_node_type_weight"] != 1.0
 
-    @staticmethod
-    def can_use_edge_types() -> bool:
+    @classmethod
+    def can_use_edge_types(cls) -> bool:
         """Returns whether the model can optionally use edge types."""
         return True
 
@@ -161,7 +148,7 @@ class Node2VecEnsmallen(AbstractEmbeddingModel):
         """Returns whether the model is parametrized to use edge types."""
         return self._model_kwargs["change_edge_type_weight"] != 1.0
 
-    @staticmethod
-    def is_stocastic() -> bool:
+    @classmethod
+    def is_stocastic(cls) -> bool:
         """Returns whether the model is stocastic and has therefore a random state."""
         return True
\ No newline at end of file
