@@ -62,8 +62,8 @@ class TransHPyKeen(EntityRelationEmbeddingModelPyKeen):
             enable_cache=enable_cache
         )
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
             **EntityRelationEmbeddingModelPyKeen.smoke_test_parameters(),
@@ -78,8 +78,8 @@ class TransHPyKeen(EntityRelationEmbeddingModelPyKeen):
             )
         }
 
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         """Return name of the model."""
         return "TransH"
 
