@@ -19,20 +19,22 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
 
     def __init__(
         self,
-        embedding_size: int = 500,
+        embedding_size: int = 100,
         negative_samples_rate: float = 0.5,
-        epochs: int = 200,
+        epochs: int = 500,
         batch_size: int = 2**10,
         early_stopping_min_delta: float = 0.001,
         early_stopping_patience: int = 10,
         learning_rate_plateau_min_delta: float = 0.001,
         learning_rate_plateau_patience: int = 5,
         use_mirrored_strategy: bool = False,
+        activation: str = "sigmoid",
+        loss: str = "binary_crossentropy",
         optimizer: str = "nadam",
         enable_cache: bool = False,
         random_state: int = 42
     ):
-        """Create new sequence Siamese model.
+        """Create new Edge-predicton based model.
 
         Parameters
         -------------------------------------------
@@ -44,7 +46,7 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
             Factor of negatives to use in every batch.
             For example, with a batch size of 128 and negative_samples_rate equal
             to 0.5, there will be 64 positives and 64 negatives.
-        epochs: int = 10
+        epochs: int = 500
             Number of epochs to train the model for.
         batch_size: int = 2**14
             Batch size to use during the training.
@@ -62,6 +64,14 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
             performance without decreasing the learning rate.
         use_mirrored_strategy: bool = False
             Whether to use mirrored strategy.
+        activation: str = "sigmoid"
+            The activation to be used.
+            For LINE models, this is the Sigmoid, while
+            for the HOPE models this is a linear activation.
+        loss: str = "binary_crossentropy"
+            Loss to be minimezed during the training of the model.
+            For LINE models, this is a  binary ceossentropy (since the output is linear)
+            while for the HOPE models this is an Mean squared error.
         optimizer: str = "nadam"
             The optimizer to be used during the training of the model.
         enable_cache: bool = False
@@ -71,6 +81,8 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
             The random state to use if the model is stocastic.
         """
         self._negative_samples_rate = negative_samples_rate
+        self._activation = activation
+        self._loss = loss
 
         super().__init__(
             embedding_size=embedding_size,
@@ -86,18 +98,12 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
             random_state=random_state
         )
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
-        """Returns parameters for smoke test."""
-        return dict(
-            **TensorFlowEmbedder.smoke_test_parameters(),
-        )
-
     def parameters(self) -> Dict[str, Any]:
         return {
             **super().parameters(),
             **dict(
-                negative_samples_rate=self._negative_samples_rate
+                negative_samples_rate=self._negative_samples_rate,
+                activation=self._activation
             )
         }
 
@@ -151,8 +157,7 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
 
         model.compile(
             optimizer=self._optimizer,
-            loss="binary_crossentropy",
-            metrics="accuracy"
+            loss=self._loss,
         )
 
         return model
@@ -167,6 +172,23 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
         """
         return max(graph.get_number_of_directed_edges() // self._batch_size, 1)
 
+    def _build_sequence(
+        self,
+        graph: Graph,
+    ) -> EdgePredictionTrainingSequence:
+        """Returns values to be fed as input into the model.
+
+        Parameters
+        ------------------
+        graph: Graph
+            The graph to build the model for.
+        """
+        return EdgePredictionTrainingSequence(
+            graph=graph,
+            negative_samples_rate=self._negative_samples_rate,
+            batch_size=self._batch_size,
+        )
+
     def _build_input(
         self,
         graph: Graph,
@@ -187,63 +209,31 @@ class EdgePredictionBasedTensorFlowEmbedders(TensorFlowEmbedder):
         except:
             AUTOTUNE = tf.data.experimental.AUTOTUNE
 
-        sequence = EdgePredictionTrainingSequence(
-            graph=graph,
-            negative_samples_rate=self._negative_samples_rate,
-            batch_size=self._batch_size,
-        )
         return (
-            sequence.into_dataset()
+            self._build_sequence(graph)
+            .into_dataset()
             .repeat()
             .prefetch(AUTOTUNE), )
 
-    @staticmethod
-    def requires_nodes_sorted_by_decreasing_node_degree() -> bool:
+    @classmethod
+    def requires_nodes_sorted_by_decreasing_node_degree(cls) -> bool:
         return False
 
-    @staticmethod
-    def is_topological() -> bool:
+    @classmethod
+    def is_topological(cls) -> bool:
         return True
 
-    @staticmethod
-    def requires_edge_weights() -> bool:
-        return False
-
-    @staticmethod
-    def requires_node_types() -> bool:
-        return False
-
-    @staticmethod
-    def requires_edge_types() -> bool:
-        return False
-
-    @staticmethod
-    def requires_positive_edge_weights() -> bool:
-        return False
-
-    @staticmethod
-    def can_use_node_types() -> bool:
+    @classmethod
+    def can_use_node_types(cls) -> bool:
         """Returns whether the model can optionally use node types."""
         return False
 
-    def is_using_node_types(self) -> bool:
-        """Returns whether the model is parametrized to use node types."""
-        return False
-
-    @staticmethod
-    def can_use_edge_weights() -> bool:
+    @classmethod
+    def can_use_edge_weights(cls) -> bool:
         """Returns whether the model can optionally use edge weights."""
         return False
 
-    def is_using_edge_weights(self) -> bool:
-        """Returns whether the model is parametrized to use edge weights."""
-        return False
-
-    @staticmethod
-    def can_use_edge_types() -> bool:
+    @classmethod
+    def can_use_edge_types(cls) -> bool:
         """Returns whether the model can optionally use edge types."""
         return False
-
-    def is_using_edge_types(self) -> bool:
-        """Returns whether the model is parametrized to use edge types."""
-        return False
