@@ -1,4 +1,4 @@
-"""First order LINE TensorFlo model."""
+"""First order LINE TensorFlow model."""
 from typing import Union, List
 
 import tensorflow as tf
@@ -13,7 +13,7 @@ from embiggen.embedders.tensorflow_embedders.edge_prediction_based_tensorflow_em
 
 
 class FirstOrderLINETensorFlow(EdgePredictionBasedTensorFlowEmbedders):
-    """First order LINE TensorFlo model."""
+    """First order LINE TensorFlow model."""
 
     def _build_edge_prediction_based_model(
         self,
@@ -31,18 +31,18 @@ class FirstOrderLINETensorFlow(EdgePredictionBasedTensorFlowEmbedders):
             The destinations nodes to be used in the model.
         """
         node_embedding = Embedding(
-            input_dim=graph.get_nodes_number(),
+            input_dim=graph.get_number_of_nodes(),
             output_dim=self._embedding_size,
             input_length=1,
             name="node_embeddings"
         )
-        return Activation("sigmoid")(Dot(axes=-1)([
+        return Activation(self._activation)(Dot(axes=-1)([
             Flatten()(node_embedding(sources)),
             Flatten()(node_embedding(destinations))
         ]))
 
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         """Returns name of the current model."""
         return "First Order LINE"
 
