@@ -75,8 +75,8 @@ class ExtraTreesNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
             random_state
         )
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
             **DecisionTreeNodeLabelPrediction.smoke_test_parameters(),
@@ -110,6 +110,6 @@ class ExtraTreesNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
         }
 
     
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         return "Extra Trees Classifier"
\ No newline at end of file
