@@ -76,8 +76,8 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
             random_state
         )
 
-    @staticmethod
-    def smoke_test_parameters() -> Dict[str, Any]:
+    @classmethod
+    def smoke_test_parameters(cls) -> Dict[str, Any]:
         """Returns parameters for smoke test."""
         return dict(
             **DecisionTreeNodeLabelPrediction.smoke_test_parameters(),
@@ -110,6 +110,6 @@ class RandomForestNodeLabelPrediction(SklearnNodeLabelPredictionAdapter):
             )
         }
 
-    @staticmethod
-    def model_name() -> str:
+    @classmethod
+    def model_name(cls) -> str:
         return "Random Forest Classifier"
\ No newline at end of file
